@@ -1,5 +1,5 @@
 from rest_framework.viewsets import ModelViewSet
-from netbox_virtual_circuit_plugin.models import SupervisorTenant, Supervisor
+from netbox_supervisor_plugin.models import SupervisorTenant, Supervisor
 from .serializers import SupervisorSerializer, SupervisorTenantSerializer
 
 
