@@ -1,11 +1,29 @@
 import django_filters
 from django.db.models import Q
 
-from utilities.filters import NameSlugSearchFilterSet, TreeNodeMultipleChoiceFilter
+from utilities.filters import TreeNodeMultipleChoiceFilter
 from tenancy.models import Tenant
 from .models import Supervisor
 
 
+class NameSlugSearchFilterSet(django_filters.FilterSet):
+    """
+    A base class for adding the search method to models which only expose the `name` and `slug` fields
+    """
+    q = django_filters.CharFilter(
+        method='search',
+        label='Search',
+    )
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(
+            models.Q(name__icontains=value) |
+            models.Q(slug__icontains=value)
+        )
+
+
 class SupervisorFilter(NameSlugSearchFilterSet):
     q = django_filters.CharFilter(
         method="search",
@@ -16,9 +34,11 @@ class SupervisorFilter(NameSlugSearchFilterSet):
         model = Supervisor
         fields = [
             'status',
+            'sid',
             'email',
             'phone',
             'tenant',
+            'tenants',
             'comments',
         ]
 
