@@ -1,7 +1,7 @@
 from django import forms
 
-from utilities.forms import BootstrapMixin
-
+from utilities.forms import BootstrapMixin, DynamicModelMultipleChoiceField, DynamicModelChoiceField
+from tenancy.models import Tenant
 from .models import VirtualCircuitStatusChoices, Supervisor, SupervisorTenant
 
 BLANK_CHOICE = (("", "---------"),)
@@ -10,6 +10,12 @@ BLANK_CHOICE = (("", "---------"),)
 # SUPERVISOR
 class SupervisorForm(BootstrapMixin, forms.ModelForm):
 
+    tenant = DynamicModelChoiceField(
+        label='Учреждение',
+        queryset=Tenant.objects.all(),
+        required=False
+    )
+
     class Meta:
         model = Supervisor
         fields = [
@@ -17,6 +23,8 @@ class SupervisorForm(BootstrapMixin, forms.ModelForm):
             'name',
             'email',
             'phone',
+            'tenant',
+            'tenants',
             'status',
             'comments',
             'is_active',
@@ -33,14 +41,31 @@ class SupervisorFilterForm(BootstrapMixin, forms.ModelForm):
         label="Статус",
         required=False
     )
+    tenant = DynamicModelMultipleChoiceField(
+        label='Учреждение',
+        queryset=Tenant.objects.all(),
+        to_field_name='id',
+        required=False,
+        null_option='None'
+    )
+
+    sid = forms.CharField(
+        required=False,
+        widget=forms.TextInput(
+            attrs={
+                'placeholder': '--------',
+            }
+        ),
+        label='Код организации'
+    )
 
     class Meta:
         model = Supervisor
         fields = [
             'q',
-            'status',
-            'comments',
-            'email',
+            # 'status',
+            # 'tenant',
+            # 'comments',
         ]
 
 
