@@ -14,7 +14,7 @@ class SupervisorTable(BaseTable):
 
     tenant = tables.LinkColumn(
         viewname='tenancy:tenant',
-        args=[Accessor('tenant.slug')]
+        args=[Accessor('tenant.id')]
     )
 
     class Meta(BaseTable.Meta):
@@ -26,6 +26,7 @@ class SupervisorTable(BaseTable):
             'email',
             'phone',
             'tenant',
+            'tenants',
             'status',
             'comments',
             'is_active',
@@ -40,7 +41,7 @@ class SupervisorTenantTable(BaseTable):
     )
     tenant = tables.LinkColumn(
         viewname='tenancy:tenant',
-        args=[Accessor('tenant.pk')]
+        args=[Accessor('tenant.id')]
     )
 
     class Meta(BaseTable.Meta):
